This is the first version of our meaningfull logging library.
The purpose of this library is to provide clear error logs for all python cloud run services running on GCP. 

loreal logging => lologging